diff --git a/wp-includes/default-filters.php b/wp-includes/default-filters.php
index 1c69f3805f..64e193fc55 100644
--- a/wp-includes/default-filters.php
+++ b/wp-includes/default-filters.php
@@ -219,7 +219,7 @@ add_action( 'wp_head',             'wp_shortlink_wp_head',            10, 0 );
 add_action( 'template_redirect',   'wp_shortlink_header',             11, 0 );
 add_action( 'wp_print_footer_scripts', '_wp_footer_scripts'                 );
 add_action( 'init',                'check_theme_switched',            99    );
-add_action( 'after_theme_change',  '_wp_sidebars_changed'                   );
+add_action( 'after_switch_theme',  '_wp_sidebars_changed'                   );
 
 if ( isset( $_GET['replytocom'] ) )
     add_filter( 'pre_option_blog_public', '__return_zero' );
diff --git a/wp-includes/theme.php b/wp-includes/theme.php
index d30a679925..1b9a36c944 100644
--- a/wp-includes/theme.php
+++ b/wp-includes/theme.php
@@ -1994,13 +1994,13 @@ function _delete_attachment_theme_mod( $id ) {
 add_action( 'delete_attachment', '_delete_attachment_theme_mod' );
 
 /**
  * Checks if a theme has been changed and runs 'after_theme_change' hook on the next WP load
  *
  * @since 3.3
- */   
+ */
 function check_theme_switched() {
 	if ( false !== ( $old_theme = get_option( 'theme_switched' ) ) && !empty( $old_theme ) ) {
-		do_action( 'after_theme_change', $old_theme );		
+		do_action( 'after_switch_theme', $old_theme );
 		update_option( 'theme_switched', false );
 	}
 }
@@ -1994,13 +1994,13 @@ function _delete_attachment_theme_mod( $id ) {
 
 /**
- * Checks if a theme has been changed and runs 'after_theme_change' hook on the next WP load
+ * Checks if a theme has been changed and runs 'after_switch_theme' hook on the next WP load
  *
  * @since 3.3